@@ -18,27 +18,26 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from helm.models.cpu import CPU
-from helm.models.mem import Mem, Swap
 from helm.models.network import Network
-from helm.models.fs import FS
 from helm.views.bar import Bar
 from helm.views.histogram import Histogram
 from helm.views.ring import Ring
 from helm.widgets.cpus import CPUs
+from helm.widgets.fss import FSs
+from helm.widgets.memswap import MemSwap
 from helm.widgets.networks import Networks
 
 from helm.core import run
 
 
 if __name__ == '__main__':
-    run(60,
-        Ring(CPU()),
-        CPUs(Histogram, view_args={'dynamic_scale': False}),
-        Networks(Histogram,
-                 view_args={'scale': (1./(2**21)*(60 * 2**10),
-                                      1./(2**21)*(250 * 2**10),
-                                      1./(2**21)*(500 * 2**10),
-                                      1./(2**21)*(1 * 2**20))}),
-        Bar(Mem()),
-        Bar(Swap()),
-        Bar(FS('/')))
+    run(widgets=(Ring(CPU()),
+                 CPUs(Histogram, view_args={'dynamic_scale': False}),
+                 Networks(Histogram,
+                          view_args={'scale': (1./(2**21)*(60 * 2**10),
+                                               1./(2**21)*(250 * 2**10),
+                                               1./(2**21)*(500 * 2**10),
+                                               1./(2**21)*(1 * 2**20))}),
+                 MemSwap(Bar),
+                 FSs(Bar))
+        )
