@@ -57,9 +57,9 @@ def draw_line(cr, x1, y1, x2, y2, thickness=1, color=WHITE,
     cr.stroke()
 
 
-def draw_ring(cr, xc, yc, r, pct, thickness=1, color=WHITE,
+def draw_ring(cr, xc, yc, r, pct, thickness=1,
               angle_start=0, angle_end=360, angle_delta=90,
-              background_ring=False, background_color=BLACK):
+              background_ring=False, fg_color=WHITE, bg_color=BLACK):
     angle_0 = (angle_start - angle_delta) * (2 * math.pi / 360)
     angle_f = (angle_end - angle_delta) * (2 * math.pi / 360)
     pct_arc = pct * (angle_f - angle_0)
@@ -68,11 +68,11 @@ def draw_ring(cr, xc, yc, r, pct, thickness=1, color=WHITE,
 
     if background_ring:
         cr.arc(xc, yc, r, angle_0, angle_f)
-        cr.set_source_rgba(*background_color)
+        cr.set_source_rgba(*bg_color)
         cr.stroke()
 
     cr.arc(xc, yc, r, angle_0, angle_0 + pct_arc)
-    cr.set_source_rgba(*color)
+    cr.set_source_rgba(*fg_color)
     cr.stroke()
 
 
