@@ -20,12 +20,11 @@
 import array
 
 import cairo
-import gobject
 import gtk
 from PIL import Image
-from Xlib import display, Xatom
 from Xlib.X import ZPixmap
-from Xlib.xobject.drawable import Pixmap
+
+from helm.theme import Theme
 
 
 # from /usr/include/X11/Xlib.h
@@ -34,6 +33,7 @@ AllPlanes = 2 ** 32 - 1
 
 class View(gtk.DrawingArea):
     __gsignals__ = {'expose-event': 'override'}
+    pix = None
 
     def __init__(self, model, scale=None):
         gtk.DrawingArea.__init__(self)
@@ -45,52 +45,41 @@ class View(gtk.DrawingArea):
         if not self.model.valid:
             return
 
-        self.display = display.Display()
-        self.screen = self.display.screen()
-        self.root = self.screen.root
-        self._XROOTPMAP_ID = self.display.intern_atom("_XROOTPMAP_ID")
-        self.ESETROOT_PMAP_ID = self.display.intern_atom("ESETROOT_PMAP_ID")
-        self.pmap = None
-
         self.background = None
         self.width = 0
         self.height = 0
 
-        gobject.timeout_add(1000, self.redraw_cb, True)
-        gobject.timeout_add(1000, self.update_cb, True)
-
     @property
     def valid(self):
         return self.model.valid
 
-    def init(self, width, height=None):
+    def init(self, theme, width, height=None):
+        class_name = self.__class__.__name__
+        self.theme_text_fg_color = getattr(theme, class_name).text.fg_color
+        self.theme_text_bg_color = getattr(theme, class_name).text.bg_color
+        self.theme_drawing_fg_color = getattr(theme,
+                                              class_name).drawing.fg_color
+        self.theme_drawing_bg_color = getattr(theme,
+                                              class_name).drawing.bg_color
+        self.theme_drawing2_fg_color = getattr(theme,
+                                               class_name).drawing2.fg_color
+        self.theme_drawing2_bg_color = getattr(theme,
+                                               class_name).drawing2.bg_color
+
         self.width = width
         if height is None:
             height = width
         self.height = height
         self.set_size_request(width, height)
 
-    def get_xid(self):
-        pmap = self.root.get_full_property(self._XROOTPMAP_ID, Xatom.PIXMAP)
-        if not pmap:
-            pmap = self.root.get_full_property(self.ESETROOT_PMAP_ID,
-                                               Xatom.PIXMAP)
-        return pmap
-
     def init_background(self):
-        # get XID
-        self.pmap = self.get_xid()
-
-        # get x-pixmap
-        pix = Pixmap(self.display.display, self.pmap.value[0])
-
         # get some informations
-        geom = pix.get_geometry()
+        # geom = View.pix.get_geometry()
         x, y = self.window.get_origin()
         width, height = self.window.get_size()
 
         # x-pixmap -> array
-        data = pix.get_image(x, y, width, height, ZPixmap, AllPlanes).data
+        data = View.pix.get_image(x, y, width, height, ZPixmap, AllPlanes).data
         image = Image.fromstring('RGB', (width, height),
                                  data, 'raw', 'BGRX')
         image_string = image.tostring()
@@ -104,33 +93,15 @@ class View(gtk.DrawingArea):
                                                       width, height)
         self.background = img_surf
 
-    def redraw_cb(self, redo=False, *args, **kwds):
-        gobject.idle_add(self.redraw_after)
-        return redo
-
-    def redraw_after(self):
-        self.emit('expose-event', None)
-
-    def update_cb(self, *args, **kwds):
-        gobject.idle_add(self.update_after)
-        return True
-
-    def update_after(self):
-        self.update()
-
-    def do_configure_event(self, *args, **kwds):
-        self.background = None
-        self.redraw_cb()
-
     def do_expose_event(self, *args, **kwds):
-        if self.pmap != self.get_xid():
-            self.background = None
+        self.redraw()
 
+    def redraw(self):
         width, height = self.window.get_size()
         pixmap = gtk.gdk.Pixmap(self.window, width, height)
         cr = pixmap.cairo_create()
         self.draw_background(cr)
-        self.draw(cr, width, height)
+        self.draw(cr)
 
         gc = self.window.new_gc()
         self.window.draw_drawable(gc, pixmap, 0, 0, 0, 0, width, height)
@@ -143,7 +114,5 @@ class View(gtk.DrawingArea):
         cr.rectangle(0, 0, width, height)
         cr.fill()
 
-    def draw(self, cr, width, height):
-        cr.set_source_rgb(0.5, 0.5, 0.5)
-        cr.rectangle(0, 0, width, height)
-        cr.fill()
+    def draw(self, cr):
+        raise NotImplementedError
