@@ -17,25 +17,27 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from helm.color import BLACK
 from helm.primitives import draw_line, draw_text, NORTHEAST
 from helm import view
 
 
 class Bar(view.View):
-    def init(self, width, height=None):
-        view.View.init(self, width, 20)
+    def init(self, theme, width, height=None):
+        view.View.init(self, theme, width, 20)
 
     def update(self):
         self.model.update()
 
-    def draw(self, cr, width, height):
+    def draw(self, cr):
         pct = self.model.pct
-        draw_line(cr, 0, 3, pct * self.width, 3, 6)
+        draw_line(cr, 0, 3, pct * self.width, 3, 6,
+                  color=self.theme_drawing_fg_color)
 
-        draw_text(cr, 0, 6, self.model.name,
-                  fg_color=(0, 1, 0, 1), bg_color=BLACK,
+        draw_text(cr, 1, 6, self.model.name,
+                  fg_color=self.theme_text_fg_color,
+                  bg_color=self.theme_text_bg_color,
                   border=1)
         draw_text(cr, self.width - 1, 6, self.model.value,
-                  fg_color=(0, 1, 0, 1), bg_color=BLACK,
+                  fg_color=self.theme_text_fg_color,
+                  bg_color=self.theme_text_bg_color,
                   border=1, reference=NORTHEAST)
