@@ -19,7 +19,6 @@
 
 import cairo
 
-from helm.color import BLACK
 from helm.primitives import draw_pixel, draw_line, draw_text, CENTER
 from helm import view
 
@@ -32,10 +31,10 @@ class Histogram(view.View):
         self.graph_height = 0
         self.text_height = 0
 
-    def init(self, width, height=None):
+    def init(self, theme, width, height=None):
         self.graph_height = 50
         self.text_height = 15
-        view.View.init(self, width, self.graph_height + self.text_height)
+        view.View.init(self, theme, width, self.graph_height + self.text_height)
         self.values = [(0, 0) for _ in xrange(width)]
 
     def get_index(self, x):
@@ -52,11 +51,12 @@ class Histogram(view.View):
         value = self.model.pct
         self.values.append((value, self.get_index(value)))
 
-    def draw(self, cr, width, height):
+    def draw(self, cr):
         # write model name
         draw_text(cr, self.width / 2, self.graph_height + self.text_height / 2,
                   self.model.name,
-                  fg_color=(0, 1, 0, 1), bg_color=BLACK,
+                  fg_color=self.theme_text_fg_color,
+                  bg_color=self.theme_text_bg_color,
                   border=1, reference=CENTER)
 
         # Horizontally flip the histogram drawing area
@@ -87,13 +87,14 @@ class Histogram(view.View):
         for i in xrange(0, nb_steps + 1):
             height = int(i * vertical_step) + .5
             draw_line(cr, 0, height, self.width + 1, height, 1,
-                      (0.56, 0.56, 0.56, 1.))
+                      self.theme_drawing2_bg_color)
 
         # draw the vertical bars
         for i, value in enumerate(values):
             draw_line(cr,
                       i + .5, 0,
-                      i + .5, int(value * vertical_step), 1)
+                      i + .5, int(value * vertical_step), 1,
+                      self.theme_drawing_fg_color)
 
         # redraw horizontal lines where there is a collision with a vertical bar
         for i in xrange(0, nb_steps + 1):
@@ -101,4 +102,4 @@ class Histogram(view.View):
             for x, value in enumerate(values):
                 height = value * vertical_step
                 if height and height >= y:
-                    draw_pixel(cr, x, y, BLACK)
+                    draw_pixel(cr, x, y, self.theme_drawing2_fg_color)
