@@ -17,7 +17,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from helm.color import BLACK, WHITE
 from helm.primitives import draw_ring, draw_text, CENTER
 from helm import view
 
@@ -30,8 +29,8 @@ class Ring(view.View):
         self.thickness = 10
         self.r = 25
 
-    def init(self, width, height=None):
-        view.View.init(self, width, width)
+    def init(self, theme, width, height=None):
+        view.View.init(self, theme, width, width)
         self.x = width / 2.
         self.y = width / 2.
         self.thickness = width / 6.
@@ -40,12 +39,15 @@ class Ring(view.View):
     def update(self):
         self.model.update()
 
-    def draw(self, cr, width, height):
+    def draw(self, cr):
         pct = self.model.pct
         draw_ring(cr, self.x, self.y, self.r, pct, thickness=self.thickness,
-                  color=WHITE, angle_start=-120, angle_end=120,
-                  background_ring=True, background_color=(0.56, 0.56, 0.56, 1.))
+                  angle_start=-120, angle_end=120,
+                  background_ring=True,
+                  fg_color=self.theme_drawing_fg_color,
+                  bg_color=self.theme_drawing_bg_color)
 
         draw_text(cr, self.x, self.y, self.model.name,
-                  fg_color=(0, 1, 0, 1), bg_color=BLACK,
+                  fg_color=self.theme_text_fg_color,
+                  bg_color=self.theme_text_bg_color,
                   border=1, reference=CENTER)
