@@ -26,10 +26,21 @@ class Widget(gtk.VBox):
         self.views = list()
         self.valid = True
 
-    def init(self, width, height=None):
+    def init(self, theme, width, height=None):
         for view in self.views:
-            view.init(width, height)
+            view.init(theme, width, height)
 
-    def do_configure_event(self, *args, **kwds):
+    def update(self):
         for view in self.views:
-            view.do_configure_event(*args, **kwds)
+            view.update()
+
+    def redraw(self):
+        for view in self.views:
+            view.redraw()
+
+    def __setattr__(self, name, value):
+        if name == 'background':
+            for view in self.views:
+                view.background = value
+        else:
+            gtk.VBox.__setattr__(self, name, value)
