@@ -17,19 +17,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# from color import BLACK, WHITE
-# from primitives import draw_line, draw_ring, draw_text, NORTHEAST
-
-from ..models.cpu import CPU
-from .. import widget
+from helm.models.cpu import CPU
+from helm import widget
 
 
 class CPUs(widget.Widget):
-    def __init__(self, view_class):
+    def __init__(self, view_class, view_args={}):
         widget.Widget.__init__(self)
         stat = open('/proc/stat').read()
         nb_cpus = int(stat.count('cpu')) - 1
         for i in xrange(nb_cpus):
-            self.views.append(view_class(CPU(i)))
+            self.views.append(view_class(CPU(i), **view_args))
         for view in self.views:
             self.pack_start(view)
