@@ -18,17 +18,24 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from os import execl
+import os
+import sys
 
-from xdg import BaseDirectory as basedir
+import glib
 
 
 def main():
-    config_file = basedir.load_first_config('helm', 'config.py')
-    if config_file is None:
+    config_dirs = (glib.get_user_config_dir(),) + glib.get_system_config_dirs()
+    for config_dir in config_dirs:
+        config_file = os.path.join(config_dir, 'helm', 'config.py')
+        if os.path.exists(config_file):
+            break
+    else:
         config_file = 'config.py'
-
-    execl('/usr/bin/env', 'env', 'python', config_file)
+        if not os.path.exists(config_file):
+            sys.exit('There is a problem with your helm installation.\n'
+                     'I can not even find the default config file.')
+    os.execl('/usr/bin/env', 'env', 'python', config_file)
 
 
 if __name__ == '__main__':
